@@ -324,6 +324,7 @@ __all__ = (
     "OperationTypeType",
     "PartitionLoadFrequencyType",
     "PasswordDataAvailableWaiterName",
+    "PayerResponsibilityType",
     "PaymentOptionType",
     "PermissionGroupType",
     "PlacementGroupStateType",
@@ -1426,6 +1427,7 @@ OnDemandAllocationStrategyType = Literal["lowestPrice", "prioritized"]
 OperationTypeType = Literal["add", "remove"]
 PartitionLoadFrequencyType = Literal["daily", "monthly", "none", "weekly"]
 PasswordDataAvailableWaiterName = Literal["password_data_available"]
+PayerResponsibilityType = Literal["ServiceOwner"]
 PaymentOptionType = Literal["AllUpfront", "NoUpfront", "PartialUpfront"]
 PermissionGroupType = Literal["all"]
 PlacementGroupStateType = Literal["available", "deleted", "deleting", "pending"]
